@@ -1,12 +1,11 @@
 package Compress::BGZF::Reader;
 
-use v5.10.1;
+use 5.012000;
 use strict;
 use warnings;
 
 use Carp;
 use Compress::Zlib;
-use IO::Uncompress::RawInflate qw/rawinflate $RawInflateError/;
 use List::Util qw/sum/;
 
 use constant BGZF_MAGIC => pack "H*", '1f8b0804';
@@ -185,8 +184,12 @@ sub _unpack_block {
         
         # decode actual content
         my $payload = _safe_sysread($self->{fh}, $payload_len);
-        rawinflate( \$payload => \$content )
-            or croak "Error inflating: $RawInflateError\n";
+        my ($i,$status) = inflateInit(-WindowBits => -&MAX_WBITS());
+        croak "Error during inflate init\n" if ($status != Z_OK);
+        ($content,$status) = $i->inflate($payload);
+        croak "Error during inflate run\n" if ($status != Z_STREAM_END);
+        #rawinflate( \$payload => \$content )
+            #or croak "Error inflating: $RawInflateError\n";
         my $crc_given = unpack 'V', _safe_sysread($self->{fh} => 4);
         croak "content CRC32 mismatch" if ( $crc_given != crc32($content) );
 
@@ -728,6 +731,24 @@ compatible with those of the htslib C<bgzip> software, and vice versa.
 
 =back
 
+=head1 NEWLINES
+
+Note that when using the tied filehandle interface, the behavior of the module
+will replicate that of a file opened in raw mode. That is, none of the Perl
+magic concerning platform-specific newline conversions will be performed. It's
+expected that users of this module will generally be seeking to predetermined
+byte offsets in a file (such as read from an index), and operations such as
+C<seek>, C<read>, and C<< <> >> are not reliable in a cross-platform way on
+files opened in 'text' mode. In other words, seeking to and reading from a
+specific offset in 'text' mode may return different results depending on the
+platform Perl is running on. This isn't an issue specific to this module but
+to Perl in general. Users should simply be aware that any data read using this
+module will retain its original line endings, which may not be the same as
+those of the current platform.
+
+For a further discussion, see
+L<http://perldoc.perl.org/perlport.html#Newlines>.
+
 =head1 CAVEATS AND BUGS
 
 This is code is in alpha testing stage and the API is not guaranteed to be
